View source: R/get_norman_data.R
| get_norman_data | R Documentation |
This function interacts with the Norman Network Database System (NDS) API.
get_norman_data(module, parameter, value, page = NULL, format = "json")
module |
A character string specifying the database module. Allowed values:
|
parameter |
A character string specifying the search parameter.
The allowed parameters depend on the selected
Parameter Descriptions:
|
value |
A character or numeric value corresponding to the chosen |
page |
(Optional) Integer or character. The page number for pagination.
If |
format |
A character string specifying the output format.
Allowed values: |
If format = "json": A list or data frame (parsed JSON).
If format = "xml": A raw character string (XML content).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.