View source: R/get_norman_empodat_batch_data.R
| get_norman_empodat_batch_data | R Documentation |
This function extends get_norman_data by supporting multiple search values
and automatic pagination for the 'empodat' module.
get_norman_empodat_batch_data(
parameter,
values,
saveToDir = NULL,
dropMemory = FALSE
)
parameter |
A character string (e.g., "nsid", "casrn"). |
values |
A character vector of values to search for (e.g., c("3380-34-5", "50-00-0")). |
saveToDir |
= when NULL files are not saved, when directory the files are saved as "values.json" file name |
dropMemory |
when true, it clears memory buffer after every loop, data will not be accessible from memory (json$Data is NULL) |
A consolidated list containing all records retrieved across all values and pages.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.